﻿
using Hotline.Share.Enums.CallCenter;
using Hotline.Share.Requests;
using XF.Utility.EnumExtensions;

namespace Hotline.Share.Dtos.TrCallCenter
{
    #region 分机
    public class TrTelDto
    {
        public string Id { get; set; }

        public string Name { get; set; }

        public string TelNo { get; set; }

        public string Description { get; set; }

        public string QueueId { get; set; }
    }

    #endregion

    #region 黑白名单
    public class TrAddBlacklistDto
    {
        public string Phone { get; set; }

        public int SpecialFlag { get; set; }
    }

    public class TrDelBlacklistDto
    {
        public string Phone { get; set; }

        public int? SpecialFlag { get; set; }
    }

    public class TrQueryBlacklistDto
    {
        public string? Phone { get; set; }

        /// <summary>
        /// 1:白名单;2:呼入黑名单;3:呼出黑名单;4:呼入呼出黑名单;
        /// </summary>
        public int? SpecialFlag { get; set; }
    }

    public class TrQueryBlacklistResponseDto
    {
        public string Id { get; set; }

        public string UserId { get; set; }

        public DateTime CreationTime { get; set; }

        public string Phone { get; set; }

        public int SpecialFlag { get; set; }

        public int? Priority { get; set; }
    }
    #endregion

    #region 登录

    public class TrOnDutyDto
    {
        public string? TelNo { get; set; }
    }

    public class TrOnDutyResponseDto
    {
        public string? TelNo { get; set; }

        public string? TelPwd { get; set; }

        public string? Description { get; set; }
        public string? QueueId { get; set; }
    }


    #endregion


    #region 通话记录（对外）

    public class ReceiveCallRecordDto
    {
        /// <summary>
        /// IPPBX用户名
        /// </summary>
        public string user { get; set; }

        /// <summary>
        /// 可直接访问的通话录音地址
        /// </summary>
        public string? recording_file_url { get; set; }

        /// <summary>
        /// 呼叫方向：呼入 in / 呼出 out
        /// </summary>
        public string call_direction { get; set; }

        /// <summary>
        /// 挂断方：主叫挂断 caller / 被叫挂断 callee / 其他未知情况
        /// </summary>
        public string hangup_side { get; set; }

        /// <summary>
        /// 坐席侧通话流水，无坐席参与则为手机侧通话流水
        /// </summary>
        public string call_accept { get; set; }

        /// <summary>
        /// 主叫号码
        /// </summary>
        public string caller_id_name { get; set; }

        /// <summary>
        /// 主叫号码
        /// </summary>
        public string caller_id_number { get; set; }

        /// <summary>
        /// 被叫号码
        /// </summary>
        public string destination_number { get; set; }

        /// <summary>
        /// 通话录音绝对路径
        /// </summary>
        public string? recording_file_name { get; set; }

        /// <summary>
        /// 通话创建时间
        /// </summary>
        public string created_time { get; set; }

        /// <summary>
        /// 接通时间
        /// </summary>
        public string? answered_time { get; set; }

        /// <summary>
        /// 挂机时间
        /// </summary>
        public string over_time { get; set; }

        /// <summary>
        /// 线路号
        /// </summary>
        public string gateway { get; set; }

        /// <summary>
        /// 呼出时自定义的内容
        /// </summary>
        public string? other_str { get; set; }

        /// <summary>
        /// 手机侧通话流水，无坐席参与则为空
        /// </summary>
        public string? other_accept { get; set; }

        /// <summary>
        /// 状态码，语音信箱：999/其他：16
        /// </summary>
        public string status { get; set; }

        /// <summary>
        /// IVR开始时间
        /// </summary>
        public string? beginIvrTime { get; set; }

        /// <summary>
        /// IVR结束时间
        /// </summary>
        public string? endIvrTime { get; set; }

        /// <summary>
        /// 开始等待时间
        /// </summary>
        public string? beginQueueTime { get; set; }

        /// <summary>
        /// 结束等待时间
        /// </summary>
        public string? endQueueTime { get; set; }

        /// <summary>
        /// 开始振铃时间
        /// </summary>
        public string? beginRingTime { get; set; }

        /// <summary>
        /// 结束振铃时间
        /// </summary>
        public string? endRingTime { get; set; }

        /// <summary>
        /// 队列ID
        /// </summary>
        public string? ola_queue { get; set; } 

        /// <summary>
        /// 批量外呼流水
        /// </summary>
        public string? batch_accept { get; set; } 

        /// <summary>
        /// IVR按键信息
        /// </summary>
        public string? ivr_dtmf { get; set; }

        /// <summary>
        /// IVR按键对应动作，需解码
        /// </summary>
        public string? dtmf_type { get; set; }
    }


    public class ReceiveCallEvaluateDto
    {
        public string dtmf { get; set; }

        public string call_accept { get; set; }
        public int type { get;set; }
    }

    #endregion

    #region 通话记录（对内）

    public record class GetCallListDto: PagedRequest
    {
        /// <summary>
        /// 主叫
        /// </summary>
        public string CPN { get; set; }
        /// <summary>
        /// 被叫
        /// </summary>
        public string CDPN { get; set; }
        /// <summary>
        /// 电话方向
        /// </summary>
        public ECallDirection? CallDirection { get; set; }

        /// <summary>
        /// 通话状态
        /// </summary>
        public EOnState? OnState { get; set; }

    }


    public class TrCallDto
    {
        /// <summary>
        /// 可直接访问的通话录音地址
        /// </summary>
        public string? RecordingFileUrl { get; set; }
        /// <summary>
        /// 呼叫方向
        /// </summary>
        public ECallDirection CallDirection { get; set; }

        /// <summary>
        /// 呼叫方向
        /// </summary>
        public string CallDirectionText => CallDirection.GetDescription();

        /// <summary>
        /// 挂断方
        /// </summary>
        public EEndBy? EndBy { get; set; }

        /// <summary>
        /// 挂断方
        /// </summary>
        public string EndByText => EndBy.GetDescription();


        /// <summary>
        /// 坐席侧通话流水，无坐席参与则为手机侧通话流水
        /// </summary>
        public string CallAccept { get; set; }
        /// <summary>
        /// 主叫
        /// </summary>
        public string CPN { get; set; }
        /// <summary>
        /// 主叫名称
        /// </summary>
        public string CPNName { get; set; }
        /// <summary>
        /// 被叫
        /// </summary>
        public string CDPN { get; set; }
        /// <summary>
        /// 通话录音绝对路径
        /// </summary>
        public string? RecordingFileName { get; set; }
        /// <summary>
        /// 通话创建时间
        /// </summary>
        public DateTime CreatedTime { get; set; }
        /// <summary>
        /// 接通时间
        /// </summary>
        public DateTime? AnsweredTime { get; set; }
        /// <summary>
        /// 挂机时间
        /// </summary>
        public DateTime OverTime { get; set; }
        /// <summary>
        /// 线路号
        /// </summary>
        public string Gateway { get; set; }
        /// <summary>
        /// 呼出时自定义的内容
        /// </summary>
        public string? OtherStr { get; set; }
        /// <summary>
        /// 手机侧通话流水，无坐席参与则为空
        /// </summary>
        public string? OtherAccept { get; set; }
        /// <summary>
        /// 状态码，语音信箱：999/其他：16
        /// </summary>
        public string Status { get; set; }
        /// <summary>
        /// IVR开始时间
        /// </summary>
        public DateTime? BeginIvrTime { get; set; }
        /// <summary>
        /// IVR结束时间
        /// </summary>
        public DateTime? EndIvrTime { get; set; }
        /// <summary>
        /// 开始等待时间
        /// </summary>
        public DateTime? BeginQueueTime { get; set; }
        /// <summary>
        /// 结束等待时间
        /// </summary>
        public DateTime? EndQueueTime { get; set; }
        /// <summary>
        /// 开始振铃时间
        /// </summary>
        public DateTime? BeginRingTime { get; set; }
        /// <summary>
        /// 结束振铃时间
        /// </summary>
        public DateTime? EndRingTimg { get; set; }
        /// <summary>
        /// 队列ID
        /// </summary>
        public string? OlaQueue { get; set; }
        /// <summary>
        /// 批量外呼流水
        /// </summary>
        public string? BatchAccept { get; set; }
        /// <summary>
        /// IVR按键信息
        /// </summary>
        public string? IvrDtmf { get; set; }
        /// <summary>
        /// IVR按键对应动作，需解码
        /// </summary>
        public string? DtmfType { get; set; }

        #region 自定义字段
        /// <summary>
        /// 通话时长（挂机时间-接通时间）
        /// </summary>
        public int Duration { get; set; }

        /// <summary>
        /// 振铃时长（振铃结束时间-振铃开始时间）
        /// </summary>
        public int RingTimes { get; set; }

        /// <summary>
        /// 排队时长（排队结束时间-排队开始时间）
        /// </summary>
        public int QueueTims { get; set; }

        /// <summary>
        /// 通话状态
        /// </summary>
        public EOnState OnState { get; set; }

        /// <summary>
        /// 通话状态
        /// </summary>
        public string OnStateText => OnState.GetDescription();
        #endregion
    }


    #endregion

    #region 关联

    public class LinkCallRecordDto
    {
        public bool IsOrder { get; set; }

        public string Id { get; set; }

        public string CallId { get; set; }
    }

    #endregion
}
