﻿using Hotline.Share.Dtos.DataSharing.Province;
using Microsoft.Extensions.DependencyInjection;
using XF.Domain.Dependency;

namespace Hotline.DataSharing.Province;

public class XieTongClient : ProvinceClient, ISingletonDependency, ISelfDependency
{
    private readonly IServiceScopeFactory _scopeFactory;

    public XieTongClient(IServiceScopeFactory scopeFactory) : base(scopeFactory)
    {
        _scopeFactory = scopeFactory;
    }

    public Task<TResponse?> RequestAsync<TRequest, TResponse>(TRequest request, CancellationToken cancellationToken)
        where TRequest : IProvinceRequest, new()
    {
        using var scope = _scopeFactory.CreateScope();
        var provider = scope.ServiceProvider;
        var channelconfigManager = provider.GetRequiredService<IChannelConfigurationManager>();

        var configProvince = channelconfigManager.GetConfigurationProvince();
        return base.RequestAsync<TRequest, TResponse>(request, configProvince.XieTong, configProvince, cancellationToken);
    }

    /// <summary>
    /// 附件获取Token
    /// </summary>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<string> GetTokenAsync(CancellationToken cancellationToken)
    {
        using var scope = _scopeFactory.CreateScope();
        var provider = scope.ServiceProvider;
        var channelconfigManager = provider.GetRequiredService<IChannelConfigurationManager>();

        var configProvince = channelconfigManager.GetConfigurationProvince();
        var token = await GetToken(configProvince.XieTong, cancellationToken);
        return token?.AccessToken ?? string.Empty;
    }
}